import os


def test_jps_client_install_simple_manifest_returns_success_response(
        jps_client,
        test_data_dir,
        new_env_name):
    # Arrange
    filename = os.path.join(test_data_dir, "simple_manifest.jps")

    # Act
    response = jps_client.install(filename, new_env_name)

    # Assert
    assert response["result"] == 0
    assert response["response"]["result"] == 0

    # TODO: check that the environment is actually up and running



class JelasticClientException(Exception):
    """
    Generic Jelastic Client Exception
    """

    pass


class ApiClientException(JelasticClientException):
    """
    Low-level API Exception
    """

    pass



import setuptools
import os

install_requires = ["httpx[http2]>=0.18"]
test_requires = [
    "pytest",
]

version = os.environ.get("JELASTIC_CLIENT_VERSION", "0.0.0")

setuptools.setup(
    name="jelastic_client",
    version=version,
    author="Laurent Michel",
    author_email="softozor@gmail.com",
    description="A jelastic client library to be used in the softozor projects",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://gitlab.hidora.com/softozor/jelastic-client",
    packages=setuptools.find_packages(),
    install_requires=install_requires,
    extras_require={
        "test": test_requires,
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
